# Django AllCaptcha

This package allows you to easily integrate captcha services in your Django project.

Currently, it supports:

- HCaptcha 
- Invisible HCaptcha 
- Recaptcha V2 Checkbox 
- Invisible Recaptcha V2 
- Recaptcha V3

[Read full documentation here](https://django-allcaptcha.readthedocs.io/en/latest/).
